==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/sr.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Учитавам преглед…",
    "Saved" : "Сачувано",
    "Admin" : "Администрација",
    "a safe home for all your data" : "сигурно место за све Ваше податке",
    "Name cannot be empty" : "Име не може бити празно",
    "The given name is too long" : "Име је предугачко",
    "The given web address is too long" : "Адреса је предугачка",
    "The given slogan is too long" : "Слоган је предугачак",
    "The given color is invalid" : "Задата боја није исправна",
    "The file was uploaded" : "Фајл је отпремљен",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Отпремани фајл превазилази смерницу upload_max_filesize у фајлу php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Отпремани фајл превазилази смерницу MAX_FILE_SIZE која је наведена у HTML обрасцу",
    "The file was only partially uploaded" : "Фајл је само делимично отпремљен",
    "No file was uploaded" : "Ниједан фајл није отпремљен",
    "Missing a temporary folder" : "Недостаје привремена фасцикла",
    "Could not write file to disk" : "Не могу да пишем фајл на диск",
    "A PHP extension stopped the file upload" : "PHP екстензија је зауставила отпремање фајла",
    "No file uploaded" : "Ниједан фајл није отпремљен",
    "Unsupported image type" : "Неподржани тип слике",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Већ користите прилагођену тему. Подешавања ове апликације ће можда бити пребрисана тиме.",
    "Theming" : "Теме",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Теме Вам омогућавају да лако измените изглед Ваше инстанце и подржаних клијената. Ово ће бити видљиво свим корисницима.",
    "Name" : "Име",
    "Reset to default" : "Ресетуј на подразумевано",
    "Web link" : "Веб веза",
    "https://…" : "https://…",
    "Slogan" : "Слоган",
    "Color" : "Боја",
    "Logo" : "Лого",
    "Upload new logo" : "Отпремите нови лого",
    "Login image" : "Слика на пријави",
    "Upload new login background" : "Отпремите нову позадину на пријави",
    "Remove background image" : "Уклони позадину",
    "Advanced options" : "Напредне опције",
    "Header logo" : "Лого заглавља",
    "Upload new header logo" : "Отпремите нови лого заглавља",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Отпремите нову favicon иконицу",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Инсталирајте Imagemagick PHP екстензију која подржава SVG слике, да аутоматски направи иконе од отпремљеног логоа и боје.",
    "You are already using a custom theme" : "Већ користите прилагођену тему",
    "reset to default" : "ресетуј на подразумевано",
    "Web address" : "Веб адреса",
    "Web address https://…" : "Веб адреса https://…",
    "There is no error, the file uploaded with success" : "Нема грешке, фајл је отпремљен успешно",
    "The uploaded file was only partially uploaded" : "Отпремани фајл је само делимично отпремљен",
    "Failed to write file to disk." : "Не могу да пишем фајл на диск",
    "A PHP extension stopped the file upload." : "PHP екстензија је зауставила отпремање фајла."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-13.0.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/sr.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Учитавам преглед…",
    "Saved" : "Сачувано",
    "Admin" : "Администрација",
    "a safe home for all your data" : "сигурно место за све Ваше податке",
    "Name cannot be empty" : "Име не може бити празно",
    "The given name is too long" : "Име је предугачко",
    "The given web address is too long" : "Адреса је предугачка",
    "The given legal notice address is too long" : "Дата адреса правног обавештења је предугачка",
    "The given privacy policy address is too long" : "Дата адреса политике приватност је предугачка",
    "The given slogan is too long" : "Слоган је предугачак",
    "The given color is invalid" : "Задата боја није исправна",
    "The file was uploaded" : "Фајл је отпремљен",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Отпремани фајл превазилази смерницу upload_max_filesize у фајлу php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Отпремани фајл превазилази смерницу MAX_FILE_SIZE која је наведена у HTML обрасцу",
    "The file was only partially uploaded" : "Фајл је само делимично отпремљен",
    "No file was uploaded" : "Ниједан фајл није отпремљен",
    "Missing a temporary folder" : "Недостаје привремена фасцикла",
    "Could not write file to disk" : "Не могу да пишем фајл на диск",
    "A PHP extension stopped the file upload" : "PHP екстензија је зауставила отпремање фајла",
    "No file uploaded" : "Ниједан фајл није отпремљен",
    "Unsupported image type" : "Неподржани тип слике",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Већ користите прилагођену тему. Подешавања ове апликације ће можда бити пребрисана тиме.",
    "Theming" : "Теме",
    "Legal notice" : "Правно обавештење",
    "Privacy policy" : "Политика приватност",
    "Adjust the Nextcloud theme" : "Прилагоди Некстклауд тему",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Теме Вам омогућавају да лако измените изглед Ваше инстанце и подржаних клијената. Ово ће бити видљиво свим корисницима.",
    "Name" : "Име",
    "Reset to default" : "Ресетуј на подразумевано",
    "Web link" : "Веб веза",
    "https://…" : "https://…",
    "Slogan" : "Слоган",
    "Color" : "Боја",
    "Logo" : "Лого",
    "Upload new logo" : "Отпремите нови лого",
    "Login image" : "Слика на пријави",
    "Upload new login background" : "Отпремите нову позадину на пријави",
    "Remove background image" : "Уклони позадину",
    "Advanced options" : "Напредне опције",
    "Legal notice link" : "Веза ка правном обавештењу",
    "Privacy policy link" : "Веза ка политици приватности",
    "Header logo" : "Лого заглавља",
    "Upload new header logo" : "Отпремите нови лого заглавља",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Отпремите нову favicon иконицу",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Инсталирајте Imagemagick PHP екстензију која подржава SVG слике, да аутоматски направи иконе од отпремљеног логоа и боје.",
    "You are already using a custom theme" : "Већ користите прилагођену тему",
    "reset to default" : "ресетуј на подразумевано",
    "Web address" : "Веб адреса",
    "Web address https://…" : "Веб адреса https://…",
    "There is no error, the file uploaded with success" : "Нема грешке, фајл је отпремљен успешно",
    "The uploaded file was only partially uploaded" : "Отпремани фајл је само делимично отпремљен",
    "Failed to write file to disk." : "Не могу да пишем фајл на диск",
    "A PHP extension stopped the file upload." : "PHP екстензија је зауставила отпремање фајла."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
